Installation — django-propaganda 1.0.1 documentation

### Navigation

- index
- previous |
- django-propaganda 1.0.1 documentation »

# Installation

1. Install the latest version:

       pip install django-propaganda

2. Add `propaganda` to your `INSTALLED_APPS` setting. One possible method:

       INSTALLED_APPS = INSTALLED_APPS + ('propaganda',)

3. If you use South for migration management (you should!) just run the migrations:

       python manage.py migrate propaganda

4. Otherwise, update your database the Django standard way (the good old `syncdb`):

       python manage.py syncdb

### Navigation

- index
- previous |
- django-propaganda 1.0.1 documentation »